You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@deltaspike.apache.org by li...@apache.org on 2012/04/13 01:22:31 UTC

[2/2] git commit: Further renames and moving

Further renames and moving


Project: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/commit/9c5194fe
Tree: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/tree/9c5194fe
Diff: http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/diff/9c5194fe

Branch: refs/heads/master
Commit: 9c5194feb7e1b464682aab8012a0d37fe530c4df
Parents: d89f26a
Author: Jason Porter <li...@apache.org>
Authored: Thu Apr 12 17:20:38 2012 -0600
Committer: Jason Porter <li...@apache.org>
Committed: Thu Apr 12 17:20:38 2012 -0600

----------------------------------------------------------------------
 .../core/api/exception/control/ExceptionEvent.java |   78 ------
 .../core/api/exception/control/ExceptionStack.java |  205 --------------
 .../api/exception/control/ExceptionToCatch.java    |  102 -------
 .../core/api/exception/control/HandlerMethod.java  |    2 +
 .../exception/control/event/ExceptionEvent.java    |   78 ++++++
 .../control/event/ExceptionStackEvent.java         |  207 +++++++++++++++
 .../control/event/ExceptionToCatchEvent.java       |  102 +++++++
 .../control/IntrospectiveExceptionEvent.java       |    2 +-
 .../exception/control/DefaultExceptionEvent.java   |   17 +-
 .../control/ExceptionHandlerDispatch.java          |   49 ++--
 .../impl/exception/control/HandlerMethodImpl.java  |    2 +-
 .../control/OutboundParameterValueRedefiner.java   |    2 +-
 .../impl/exception/control/event/EventTest.java    |    8 +-
 .../control/flow/AbortingBreadthFirstHandler.java  |    2 +-
 .../control/flow/AbortingDepthHandler.java         |    2 +-
 .../control/flow/BreadthFirstAbortControlTest.java |    4 +-
 .../control/flow/DepthAbortControlTest.java        |    4 +-
 .../control/flow/ExceptionHandledHandler.java      |    2 +-
 .../control/flow/HandledExceptionHandlerTest.java  |   10 +-
 .../control/flow/ProceedCauseHandler.java          |    2 +-
 .../control/flow/ProceedCauseHandlerTest.java      |    4 +-
 .../exception/control/flow/RethrowHandler.java     |    2 +-
 .../impl/exception/control/flow/RethrowTest.java   |    6 +-
 .../control/flow/ThrowingNewExceptionTest.java     |    6 +-
 .../exception/control/flow/ThrowingNewHandler.java |    2 +-
 .../control/handler/BadInjectionPointHandler.java  |    2 +-
 .../control/handler/CalledExceptionHandler.java    |    2 +-
 .../control/handler/CallingHandlersTest.java       |   14 +-
 .../control/handler/ExtensionExceptionHandler.java |    2 +-
 .../handler/HandlerWhichThrowsExceptions.java      |    2 +-
 .../exception/control/handler/UnMuteHandler.java   |    2 +-
 .../control/handler/UnMuteHandlerTest.java         |    4 +-
 .../control/traversal/ExceptionHandlerMethods.java |    2 +-
 .../control/traversal/TraversalPathTest.java       |    4 +-
 34 files changed, 470 insertions(+), 464 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionEvent.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionEvent.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionEvent.java
deleted file mode 100644
index 872b1c3..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionEvent.java
+++ /dev/null
@@ -1,78 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-
-package org.apache.deltaspike.core.api.exception.control;
-
-/**
- * Payload for an exception to be handled.  Implementations of this interface should not expose internals and remain
- * immutable for this contract.
- *
- * @param <T> Exception type this event represents
- */
-public interface ExceptionEvent<T extends Throwable>
-{
-    /**
-     * The exception causing this event.
-     */
-    T getException();
-
-    /**
-     * Instructs the dispatcher to abort further processing of handlers.
-     */
-    void abort();
-
-    /**
-     * Instructs the dispatcher to throw the original exception after handler processing.
-     */
-    void throwOriginal();
-
-    /**
-     * Instructs the dispatcher to terminate additional handler processing and mark the event as handled.
-     */
-    void handled();
-
-    /**
-     * Default instruction to dispatcher, continues handler processing.
-     */
-    void handledAndContinue();
-
-    /**
-     * Similar to {@link ExceptionEvent#handledAndContinue()},
-     * but instructs the dispatcher to markHandled to the next element
-     * in the cause chain without processing additional handlers for this cause chain element.
-     */
-    void skipCause();
-
-    /**
-     * Instructs the dispatcher to allow this handler to be invoked again.
-     */
-    void unmute();
-
-    /**
-     * Rethrow the exception, but use the given exception instead of the original.
-     *
-     * @param t Exception to be thrown in place of the original.
-     */
-    void rethrow(Throwable t);
-
-    /**
-     * Check to see if this exception has been handled.
-     */
-    boolean isMarkedHandled();
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionStack.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionStack.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionStack.java
deleted file mode 100644
index 88b231e..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionStack.java
+++ /dev/null
@@ -1,205 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-
-package org.apache.deltaspike.core.api.exception.control;
-
-import javax.enterprise.inject.Typed;
-import java.io.Serializable;
-import java.sql.SQLException;
-import java.util.ArrayDeque;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Deque;
-
-/**
- * Information about the current exception and exception cause container.  This object is not immutable.
- */
-@SuppressWarnings("CdiManagedBeanInconsistencyInspection")
-@Typed()
-public class ExceptionStack implements Serializable
-{
-    private static final long serialVersionUID = -6069790756478700680L;
-
-    private boolean root;
-    private boolean last;
-    private int initialStackSize;
-    private Throwable next;
-    private Collection<ExceptionStackItem> remaining;
-    private Deque<ExceptionStackItem> exceptionStackItems;
-    // private Deque<ExceptionStackItem> origExceptionStackItems; // TODO: Later
-    private Collection<Throwable> causes;
-    private Throwable current;
-
-    /**
-     * Builds the stack from the given exception.
-     *
-     * @param exception Caught exception
-     */
-    public ExceptionStack(final Throwable exception)
-    {
-        if (exception == null)
-        {
-            throw new IllegalArgumentException("exception must not be null");
-        }
-
-        Throwable e = exception;
-        this.exceptionStackItems = new ArrayDeque<ExceptionStackItem>();
-
-        do
-        {
-            this.exceptionStackItems.addFirst(new ExceptionStackItem(e));
-            if (e instanceof SQLException)
-            {
-                SQLException sqlException = (SQLException) e;
-
-                while (sqlException.getNextException() != null)
-                {
-                    sqlException = sqlException.getNextException();
-                    this.exceptionStackItems.addFirst(new ExceptionStackItem(sqlException));
-                }
-            }
-            e = e.getCause();
-        }
-        while (e != null);
-
-        this.initialStackSize = this.exceptionStackItems.size();
-        this.causes = this.createThrowableCollection(exceptionStackItems);
-        // TODO: Later this.origExceptionStackItems = new ArrayDeque<ExceptionStackItem>(exceptionStackItems);
-        this.init();
-
-    }
-
-    private void init()
-    {
-        this.root = this.exceptionStackItems.size() == this.initialStackSize;
-
-        if (!this.exceptionStackItems.isEmpty())
-        {
-            this.current = this.exceptionStackItems.removeFirst().getThrowable();
-            this.remaining = Collections.unmodifiableCollection(this.exceptionStackItems);
-        }
-        else
-        {
-            this.remaining = Collections.emptyList();
-            this.current = null;
-        }
-
-        this.last = this.remaining.isEmpty();
-        this.next = (this.last) ? null : this.exceptionStackItems.peekFirst().getThrowable();
-    }
-
-    private Collection<ExceptionStackItem> createExceptionStackFrom(Collection<Throwable> throwables)
-    {
-        final Deque<ExceptionStackItem> returningCollection = new ArrayDeque<ExceptionStackItem>(throwables.size());
-
-        for (Throwable t : throwables)
-        {
-            returningCollection.addFirst(new ExceptionStackItem(t));
-        }
-
-        return returningCollection;
-    }
-
-    private Collection<Throwable> createThrowableCollection(final Collection<ExceptionStackItem> exceptionStackItems)
-    {
-        // allow current
-        final Deque<Throwable> returningCollection = new ArrayDeque<Throwable>(exceptionStackItems.size() + 1);
-
-        for (ExceptionStackItem item : exceptionStackItems)
-        {
-            returningCollection.addFirst(item.getThrowable());
-        }
-
-        return returningCollection;
-    }
-
-    public Collection<Throwable> getCauseElements()
-    {
-        return Collections.unmodifiableCollection(this.causes);
-    }
-
-    /**
-     * Test if iteration is finished
-     *
-     * @return finished with iteration
-     */
-    public boolean isLast()
-    {
-        return this.last;
-    }
-
-    public Throwable getNext()
-    {
-        return this.next;
-    }
-
-    public Collection<Throwable> getRemaining()
-    {
-        return Collections.unmodifiableCollection(this.createThrowableCollection(this.remaining));
-    }
-
-    /**
-     * Tests if the current exception is the root exception
-     *
-     * @return Returns true if iteration is at the root exception (top of the inverted stack)
-     */
-    public boolean isRoot()
-    {
-        return this.root;
-    }
-
-    /**
-     * Current exception in the iteration
-     *
-     * @return current exception
-     */
-    public Throwable getCurrent()
-    {
-        return this.current;
-    }
-
-    /**
-     * Internal only.
-     *
-     * @param elements new stack.
-     */
-    public void setCauseElements(Collection<Throwable> elements)
-    {
-        this.exceptionStackItems = new ArrayDeque<ExceptionStackItem>(this.createExceptionStackFrom(elements));
-        this.init();
-    }
-
-    /**
-     * Internal only.
-     */
-    public void skipCause()
-    {
-        this.init();
-    }
-
-    /**
-     * Done later
-     * The original exception stack if it has been changed.
-     *
-     * @return The original exception stack
-
-    public Deque<ExceptionStackItem> getOrigExceptionStackItems() {
-    }
-     */
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionToCatch.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionToCatch.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionToCatch.java
deleted file mode 100644
index a1ebc2d..0000000
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/ExceptionToCatch.java
+++ /dev/null
@@ -1,102 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements. See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership. The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations
- * under the License.
- */
-
-package org.apache.deltaspike.core.api.exception.control;
-
-import javax.enterprise.inject.Typed;
-import java.io.Serializable;
-import java.lang.annotation.Annotation;
-import java.util.Collections;
-import java.util.HashSet;
-import java.util.Set;
-
-/**
- * Entry point event into the Catch system.  This object is nearly immutable, the only mutable portion
- * is the handled flag.
- */
-@SuppressWarnings("CdiManagedBeanInconsistencyInspection")
-@Typed()
-public class ExceptionToCatch implements Serializable
-{
-    private static final long serialVersionUID = 2646115104528108266L;
-
-    private Throwable exception;
-    private boolean handled;
-    private transient Set<Annotation> qualifiers;
-
-    /**
-     * Constructor that adds qualifiers for the handler(s) to run.
-     * Typically only integrators will be using this constructor.
-     *
-     * @param exception  Exception to handle
-     * @param qualifiers qualifiers to use to narrow the handlers called
-     */
-    public ExceptionToCatch(Throwable exception, Annotation... qualifiers)
-    {
-        this.exception = exception;
-        this.qualifiers = new HashSet<Annotation>();
-        Collections.addAll(this.qualifiers, qualifiers);
-    }
-
-    /**
-     * Basic constructor without any qualifiers defined.
-     *
-     * @param exception Exception to handle.
-     */
-    public ExceptionToCatch(Throwable exception)
-    {
-        this.exception = exception;
-        this.qualifiers = Collections.emptySet();
-    }
-
-    public Throwable getException()
-    {
-        return this.exception;
-    }
-
-    /**
-     * Internal only.
-     *
-     * @param handled new value
-     */
-    public void setHandled(boolean handled)
-    {
-        this.handled = handled;
-    }
-
-    /**
-     * Test to see if the exception has been handled via Solder Catch.
-     *
-     * @return test if the exception has been through Solder Catch handling.
-     */
-    public boolean isHandled()
-    {
-        return this.handled;
-    }
-
-    /**
-     * Qualifiers with which the instance was created.
-     *
-     * @return Qualifiers with which the instance was created.
-     */
-    public Set<Annotation> getQualifiers()
-    {
-        return Collections.unmodifiableSet(this.qualifiers);
-    }
-}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/HandlerMethod.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/HandlerMethod.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/HandlerMethod.java
index f1a574a..d802645 100644
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/HandlerMethod.java
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/HandlerMethod.java
@@ -19,6 +19,8 @@
 
 package org.apache.deltaspike.core.api.exception.control;
 
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
+
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Type;
 import java.util.Set;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionEvent.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionEvent.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionEvent.java
new file mode 100644
index 0000000..c4a2402
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionEvent.java
@@ -0,0 +1,78 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+package org.apache.deltaspike.core.api.exception.control.event;
+
+/**
+ * Payload for an exception to be handled.  Implementations of this interface should not expose internals and remain
+ * immutable for this contract.
+ *
+ * @param <T> Exception type this event represents
+ */
+public interface ExceptionEvent<T extends Throwable>
+{
+    /**
+     * The exception causing this event.
+     */
+    T getException();
+
+    /**
+     * Instructs the dispatcher to abort further processing of handlers.
+     */
+    void abort();
+
+    /**
+     * Instructs the dispatcher to throw the original exception after handler processing.
+     */
+    void throwOriginal();
+
+    /**
+     * Instructs the dispatcher to terminate additional handler processing and mark the event as handled.
+     */
+    void handled();
+
+    /**
+     * Default instruction to dispatcher, continues handler processing.
+     */
+    void handledAndContinue();
+
+    /**
+     * Similar to {@link ExceptionEvent#handledAndContinue()},
+     * but instructs the dispatcher to markHandled to the next element
+     * in the cause chain without processing additional handlers for this cause chain element.
+     */
+    void skipCause();
+
+    /**
+     * Instructs the dispatcher to allow this handler to be invoked again.
+     */
+    void unmute();
+
+    /**
+     * Rethrow the exception, but use the given exception instead of the original.
+     *
+     * @param t Exception to be thrown in place of the original.
+     */
+    void rethrow(Throwable t);
+
+    /**
+     * Check to see if this exception has been handled.
+     */
+    boolean isMarkedHandled();
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionStackEvent.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionStackEvent.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionStackEvent.java
new file mode 100644
index 0000000..9d6695a
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionStackEvent.java
@@ -0,0 +1,207 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+package org.apache.deltaspike.core.api.exception.control.event;
+
+import org.apache.deltaspike.core.api.exception.control.ExceptionStackItem;
+
+import javax.enterprise.inject.Typed;
+import java.io.Serializable;
+import java.sql.SQLException;
+import java.util.ArrayDeque;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Deque;
+
+/**
+ * Information about the current exception and exception cause container.  This object is not immutable.
+ */
+@SuppressWarnings("CdiManagedBeanInconsistencyInspection")
+@Typed()
+public class ExceptionStackEvent implements Serializable
+{
+    private static final long serialVersionUID = -6069790756478700680L;
+
+    private boolean root;
+    private boolean last;
+    private int initialStackSize;
+    private Throwable next;
+    private Collection<ExceptionStackItem> remaining;
+    private Deque<ExceptionStackItem> exceptionStackItems;
+    // private Deque<ExceptionStackItem> origExceptionStackItems; // TODO: Later
+    private Collection<Throwable> causes;
+    private Throwable current;
+
+    /**
+     * Builds the stack from the given exception.
+     *
+     * @param exception Caught exception
+     */
+    public ExceptionStackEvent(final Throwable exception)
+    {
+        if (exception == null)
+        {
+            throw new IllegalArgumentException("exception must not be null");
+        }
+
+        Throwable e = exception;
+        this.exceptionStackItems = new ArrayDeque<ExceptionStackItem>();
+
+        do
+        {
+            this.exceptionStackItems.addFirst(new ExceptionStackItem(e));
+            if (e instanceof SQLException)
+            {
+                SQLException sqlException = (SQLException) e;
+
+                while (sqlException.getNextException() != null)
+                {
+                    sqlException = sqlException.getNextException();
+                    this.exceptionStackItems.addFirst(new ExceptionStackItem(sqlException));
+                }
+            }
+            e = e.getCause();
+        }
+        while (e != null);
+
+        this.initialStackSize = this.exceptionStackItems.size();
+        this.causes = this.createThrowableCollection(exceptionStackItems);
+        // TODO: Later this.origExceptionStackItems = new ArrayDeque<ExceptionStackItem>(exceptionStackItems);
+        this.init();
+
+    }
+
+    private void init()
+    {
+        this.root = this.exceptionStackItems.size() == this.initialStackSize;
+
+        if (!this.exceptionStackItems.isEmpty())
+        {
+            this.current = this.exceptionStackItems.removeFirst().getThrowable();
+            this.remaining = Collections.unmodifiableCollection(this.exceptionStackItems);
+        }
+        else
+        {
+            this.remaining = Collections.emptyList();
+            this.current = null;
+        }
+
+        this.last = this.remaining.isEmpty();
+        this.next = (this.last) ? null : this.exceptionStackItems.peekFirst().getThrowable();
+    }
+
+    private Collection<ExceptionStackItem> createExceptionStackFrom(Collection<Throwable> throwables)
+    {
+        final Deque<ExceptionStackItem> returningCollection = new ArrayDeque<ExceptionStackItem>(throwables.size());
+
+        for (Throwable t : throwables)
+        {
+            returningCollection.addFirst(new ExceptionStackItem(t));
+        }
+
+        return returningCollection;
+    }
+
+    private Collection<Throwable> createThrowableCollection(final Collection<ExceptionStackItem> exceptionStackItems)
+    {
+        // allow current
+        final Deque<Throwable> returningCollection = new ArrayDeque<Throwable>(exceptionStackItems.size() + 1);
+
+        for (ExceptionStackItem item : exceptionStackItems)
+        {
+            returningCollection.addFirst(item.getThrowable());
+        }
+
+        return returningCollection;
+    }
+
+    public Collection<Throwable> getCauseElements()
+    {
+        return Collections.unmodifiableCollection(this.causes);
+    }
+
+    /**
+     * Test if iteration is finished
+     *
+     * @return finished with iteration
+     */
+    public boolean isLast()
+    {
+        return this.last;
+    }
+
+    public Throwable getNext()
+    {
+        return this.next;
+    }
+
+    public Collection<Throwable> getRemaining()
+    {
+        return Collections.unmodifiableCollection(this.createThrowableCollection(this.remaining));
+    }
+
+    /**
+     * Tests if the current exception is the root exception
+     *
+     * @return Returns true if iteration is at the root exception (top of the inverted stack)
+     */
+    public boolean isRoot()
+    {
+        return this.root;
+    }
+
+    /**
+     * Current exception in the iteration
+     *
+     * @return current exception
+     */
+    public Throwable getCurrent()
+    {
+        return this.current;
+    }
+
+    /**
+     * Internal only.
+     *
+     * @param elements new stack.
+     */
+    public void setCauseElements(Collection<Throwable> elements)
+    {
+        this.exceptionStackItems = new ArrayDeque<ExceptionStackItem>(this.createExceptionStackFrom(elements));
+        this.init();
+    }
+
+    /**
+     * Internal only.
+     */
+    public void skipCause()
+    {
+        this.init();
+    }
+
+    /**
+     * Done later
+     * The original exception stack if it has been changed.
+     *
+     * @return The original exception stack
+
+    public Deque<ExceptionStackItem> getOrigExceptionStackItems() {
+    }
+     */
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionToCatchEvent.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionToCatchEvent.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionToCatchEvent.java
new file mode 100644
index 0000000..4872b93
--- /dev/null
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/exception/control/event/ExceptionToCatchEvent.java
@@ -0,0 +1,102 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements. See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership. The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied. See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
+package org.apache.deltaspike.core.api.exception.control.event;
+
+import javax.enterprise.inject.Typed;
+import java.io.Serializable;
+import java.lang.annotation.Annotation;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
+
+/**
+ * Entry point event into the Catch system.  This object is nearly immutable, the only mutable portion
+ * is the handled flag.
+ */
+@SuppressWarnings("CdiManagedBeanInconsistencyInspection")
+@Typed()
+public class ExceptionToCatchEvent implements Serializable
+{
+    private static final long serialVersionUID = 2646115104528108266L;
+
+    private Throwable exception;
+    private boolean handled;
+    private transient Set<Annotation> qualifiers;
+
+    /**
+     * Constructor that adds qualifiers for the handler(s) to run.
+     * Typically only integrators will be using this constructor.
+     *
+     * @param exception  Exception to handle
+     * @param qualifiers qualifiers to use to narrow the handlers called
+     */
+    public ExceptionToCatchEvent(Throwable exception, Annotation... qualifiers)
+    {
+        this.exception = exception;
+        this.qualifiers = new HashSet<Annotation>();
+        Collections.addAll(this.qualifiers, qualifiers);
+    }
+
+    /**
+     * Basic constructor without any qualifiers defined.
+     *
+     * @param exception Exception to handle.
+     */
+    public ExceptionToCatchEvent(Throwable exception)
+    {
+        this.exception = exception;
+        this.qualifiers = Collections.emptySet();
+    }
+
+    public Throwable getException()
+    {
+        return this.exception;
+    }
+
+    /**
+     * Internal only.
+     *
+     * @param handled new value
+     */
+    public void setHandled(boolean handled)
+    {
+        this.handled = handled;
+    }
+
+    /**
+     * Test to see if the exception has been handled via Solder Catch.
+     *
+     * @return test if the exception has been through Solder Catch handling.
+     */
+    public boolean isHandled()
+    {
+        return this.handled;
+    }
+
+    /**
+     * Qualifiers with which the instance was created.
+     *
+     * @return Qualifiers with which the instance was created.
+     */
+    public Set<Annotation> getQualifiers()
+    {
+        return Collections.unmodifiableSet(this.qualifiers);
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/spi/exception/control/IntrospectiveExceptionEvent.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/spi/exception/control/IntrospectiveExceptionEvent.java b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/spi/exception/control/IntrospectiveExceptionEvent.java
index e4a7c3b..f7a2e89 100644
--- a/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/spi/exception/control/IntrospectiveExceptionEvent.java
+++ b/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/spi/exception/control/IntrospectiveExceptionEvent.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.core.spi.exception.control;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandlingFlow;
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/DefaultExceptionEvent.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/HandlerMethodImpl.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/HandlerMethodImpl.java
index 27e1b22..42ca2ff 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/HandlerMethodImpl.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/HandlerMethodImpl.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.core.impl.exception.control;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.HandlerMethod;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 import org.apache.deltaspike.core.api.literal.AnyLiteral;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/OutboundParameterValueRedefiner.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/OutboundParameterValueRedefiner.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/OutboundParameterValueRedefiner.java
index 11780e0..1857dfc 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/OutboundParameterValueRedefiner.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/OutboundParameterValueRedefiner.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.core.impl.exception.control;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.metadata.builder.ParameterValueRedefiner;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/event/EventTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/event/EventTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/event/EventTest.java
index 72e8516..670c071 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/event/EventTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/event/EventTest.java
@@ -20,9 +20,9 @@
 package org.apache.deltaspike.test.core.impl.exception.control.event;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.core.spi.exception.control.IntrospectiveExceptionEvent;
@@ -76,13 +76,13 @@ public class EventTest
     @Test
     public void assertEventIsCreatedCorrectly()
     {
-        bm.fireEvent(new ExceptionToCatch(new NullPointerException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new NullPointerException()));
     }
 
     @Test
     public void assertEventWithQualifiersIsCreatedCorrectly()
     {
-        this.bm.fireEvent(new ExceptionToCatch(new NullPointerException(), new EventQualifierLiteral()));
+        this.bm.fireEvent(new ExceptionToCatchEvent(new NullPointerException(), new EventQualifierLiteral()));
     }
 
     public void verifyDescEvent(@BeforeHandles IntrospectiveExceptionEvent<NullPointerException> event)

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingBreadthFirstHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingBreadthFirstHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingBreadthFirstHandler.java
index 5da3be3..71275af 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingBreadthFirstHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingBreadthFirstHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingDepthHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingDepthHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingDepthHandler.java
index f4446b6..90fe89b 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingDepthHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/AbortingDepthHandler.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/BreadthFirstAbortControlTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/BreadthFirstAbortControlTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/BreadthFirstAbortControlTest.java
index a82997a..f7ae3ca 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/BreadthFirstAbortControlTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/BreadthFirstAbortControlTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -68,7 +68,7 @@ public class BreadthFirstAbortControlTest
     @Test
     public void assertNoOtherHandlersCalledAfterAbort()
     {
-        bm.fireEvent(new ExceptionToCatch(new NullPointerException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new NullPointerException()));
         assertTrue(this.abortingBreadthFirstHandler.isAbortCalled());
         assertFalse(this.abortingBreadthFirstHandler.isProceedCalled());
     }

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/DepthAbortControlTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/DepthAbortControlTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/DepthAbortControlTest.java
index 1f534ce..04744bc 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/DepthAbortControlTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/DepthAbortControlTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -68,7 +68,7 @@ public class DepthAbortControlTest
     @Test
     public void assertNoOtherHandlersCalledAfterAbort()
     {
-        bm.fireEvent(new ExceptionToCatch(new NullPointerException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new NullPointerException()));
         assertTrue(this.abortingDepthHandler.isAbortCalled());
         assertFalse(this.abortingDepthHandler.isProceedCalled());
     }

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ExceptionHandledHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ExceptionHandledHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ExceptionHandledHandler.java
index 7ab90fc..4bf6480 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ExceptionHandledHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ExceptionHandledHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/HandledExceptionHandlerTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/HandledExceptionHandlerTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/HandledExceptionHandlerTest.java
index 01a2c94..bdd2cd7 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/HandledExceptionHandlerTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/HandledExceptionHandlerTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -68,18 +68,18 @@ public class HandledExceptionHandlerTest
     @Test
     public void assertNoHandlersAfterHandledAreCalled()
     {
-        final ExceptionToCatch catchEntry = new ExceptionToCatch(new Exception(
+        final ExceptionToCatchEvent entryEvent = new ExceptionToCatchEvent(new Exception(
                 new NullPointerException()));
-        bm.fireEvent(catchEntry);
+        bm.fireEvent(entryEvent);
         assertTrue(this.exceptionHandledHandler.isNpeDescCalled());
         assertFalse(this.exceptionHandledHandler.isExAscCalled());
-        assertTrue(catchEntry.isHandled());
+        assertTrue(entryEvent.isHandled());
     }
 
     @Test
     public void assertNoHandlersAfterHandledAreCalledDesc()
     {
-        final ExceptionToCatch event = new ExceptionToCatch(new Exception(new IllegalArgumentException()));
+        final ExceptionToCatchEvent event = new ExceptionToCatchEvent(new Exception(new IllegalArgumentException()));
         bm.fireEvent(event);
         assertTrue(this.exceptionHandledHandler.isIaeAscCalled());
         assertFalse(this.exceptionHandledHandler.isExAscCalled());

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandler.java
index d5ddfd4..12dbb4c 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandlerTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandlerTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandlerTest.java
index 9192bc0..0226713 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandlerTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ProceedCauseHandlerTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -67,7 +67,7 @@ public class ProceedCauseHandlerTest
     @Test
     public void assertCorrectNumberOfHandlerCallsForProceedCause()
     {
-        bm.fireEvent(new ExceptionToCatch(new Exception(new IllegalArgumentException(new NullPointerException()))));
+        bm.fireEvent(new ExceptionToCatchEvent(new Exception(new IllegalArgumentException(new NullPointerException()))));
         assertEquals(0, this.proceedCauseHandler.getBreadthFirstNpeLowerPrecedenceCalled());
         assertEquals(1, this.proceedCauseHandler.getBreadthFirstNpeCalled());
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowHandler.java
index e38cdbd..b6045d8 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowTest.java
index 43ea066..65ed5e6 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/RethrowTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -62,12 +62,12 @@ public class RethrowTest
     @Test(expected = NullPointerException.class)
     public void assertOutboundRethrow()
     {
-        bm.fireEvent(new ExceptionToCatch(new NullPointerException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new NullPointerException()));
     }
 
     @Test(expected = IllegalArgumentException.class)
     public void assertInboundRethrow()
     {
-        bm.fireEvent(new ExceptionToCatch(new IllegalArgumentException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new IllegalArgumentException()));
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewExceptionTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewExceptionTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewExceptionTest.java
index e80dc95..db1dd5b 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewExceptionTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewExceptionTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -62,12 +62,12 @@ public class ThrowingNewExceptionTest
     @Test(expected = UnsupportedOperationException.class)
     public void assertOutboundRethrow()
     {
-        bm.fireEvent(new ExceptionToCatch(new NullPointerException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new NullPointerException()));
     }
 
     @Test(expected = UnsupportedOperationException.class)
     public void assertInboundRethrow()
     {
-        bm.fireEvent(new ExceptionToCatch(new IllegalArgumentException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new IllegalArgumentException()));
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewHandler.java
index 835afb1..7856b43 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/flow/ThrowingNewHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.flow;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/BadInjectionPointHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/BadInjectionPointHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/BadInjectionPointHandler.java
index c8e9213..2a19fac 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/BadInjectionPointHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/BadInjectionPointHandler.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CalledExceptionHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CalledExceptionHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CalledExceptionHandler.java
index f509ea6..36c1762 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CalledExceptionHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CalledExceptionHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CallingHandlersTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CallingHandlersTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CallingHandlersTest.java
index 4ca61c7..81ab272 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CallingHandlersTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/CallingHandlersTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -69,7 +69,7 @@ public class CallingHandlersTest
     @Test
     public void assertOutboundHanldersAreCalled()
     {
-        bm.fireEvent(new ExceptionToCatch(new IllegalArgumentException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new IllegalArgumentException()));
 
         assertTrue(this.calledExceptionHandler.isOutboundHandlerCalled());
     }
@@ -78,7 +78,7 @@ public class CallingHandlersTest
     public void assertOutboundHanldersAreCalledOnce()
     {
         this.calledExceptionHandler.setOutboundHandlerTimesCalled(0);
-        bm.fireEvent(new ExceptionToCatch(new IllegalArgumentException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new IllegalArgumentException()));
         assertEquals(1, this.calledExceptionHandler.getOutboundHandlerTimesCalled());
     }
 
@@ -86,28 +86,28 @@ public class CallingHandlersTest
     public void assertInboundHanldersAreCalledOnce()
     {
         this.calledExceptionHandler.setInboundHandlerTimesCalled(0);
-        bm.fireEvent(new ExceptionToCatch(new IllegalArgumentException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new IllegalArgumentException()));
         assertEquals(1, this.calledExceptionHandler.getInboundHandlerTimesCalled());
     }
 
     @Test
     public void assertAdditionalParamsAreInjected()
     {
-        bm.fireEvent(new ExceptionToCatch(new RuntimeException(new IllegalArgumentException())));
+        bm.fireEvent(new ExceptionToCatchEvent(new RuntimeException(new IllegalArgumentException())));
         assertTrue(this.calledExceptionHandler.isBeanmanagerInjected());
     }
 
     //@Test //TODO discuss this test
     public void assertAdditionalParamsAreInjectedWithDifferentHandlerLocation()
     {
-        bm.fireEvent(new ExceptionToCatch(new SQLException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new SQLException()));
         assertTrue(this.calledExceptionHandler.isLocationDifferBeanmanagerInjected());
     }
 
     @Test
     public void assertProtectedHandlersAreCalled()
     {
-        bm.fireEvent(new ExceptionToCatch(new IllegalStateException()));
+        bm.fireEvent(new ExceptionToCatchEvent(new IllegalStateException()));
         assertTrue(this.calledExceptionHandler.isProtectedHandlerCalled());
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/ExtensionExceptionHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/ExtensionExceptionHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/ExtensionExceptionHandler.java
index aa2eee8..1b77174 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/ExtensionExceptionHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/ExtensionExceptionHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 import org.apache.deltaspike.test.core.impl.exception.control.extension.Account;

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/HandlerWhichThrowsExceptions.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/HandlerWhichThrowsExceptions.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/HandlerWhichThrowsExceptions.java
index 27ddde9..e4d0d0a 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/HandlerWhichThrowsExceptions.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/HandlerWhichThrowsExceptions.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandler.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandler.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandler.java
index e377160..ca0da0a 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandler.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandler.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandlerTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandlerTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandlerTest.java
index 247f2ff..ffd969e 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandlerTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/handler/UnMuteHandlerTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.handler;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -67,7 +67,7 @@ public class UnMuteHandlerTest
     @Test
     public void assertCorrectNumberOfCallsForUnMute()
     {
-        bm.fireEvent(new ExceptionToCatch(new Exception(new NullPointerException())));
+        bm.fireEvent(new ExceptionToCatchEvent(new Exception(new NullPointerException())));
 
         assertEquals(2, this.unMuteHandler.getDepthFirstNumberCalled());
         assertEquals(2, this.unMuteHandler.getBreadthFirstNumberCalled());

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/ExceptionHandlerMethods.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/ExceptionHandlerMethods.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/ExceptionHandlerMethods.java
index 9163df2..85b73ab 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/ExceptionHandlerMethods.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/ExceptionHandlerMethods.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.test.core.impl.exception.control.traversal;
 
 import org.apache.deltaspike.core.api.exception.control.BeforeHandles;
-import org.apache.deltaspike.core.api.exception.control.ExceptionEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionEvent;
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandler;
 import org.apache.deltaspike.core.api.exception.control.Handles;
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/TraversalPathTest.java
----------------------------------------------------------------------
diff --git a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/TraversalPathTest.java b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/TraversalPathTest.java
index 51633c7..4c0d25f 100644
--- a/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/TraversalPathTest.java
+++ b/deltaspike/core/impl/src/test/java/org/apache/deltaspike/test/core/impl/exception/control/traversal/TraversalPathTest.java
@@ -19,7 +19,7 @@
 
 package org.apache.deltaspike.test.core.impl.exception.control.traversal;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.provider.BeanManagerProvider;
 import org.apache.deltaspike.test.util.ArchiveUtils;
 import org.jboss.arquillian.container.test.api.Deployment;
@@ -71,7 +71,7 @@ public class TraversalPathTest
         Exceptions.Exception1 exception = new Exceptions.Exception1(new
                 Exceptions.Exception2(new Exceptions.Exception3()));
 
-        manager.fireEvent(new ExceptionToCatch(exception));
+        manager.fireEvent(new ExceptionToCatchEvent(exception));
 
         /*
             handleException3SuperclassBF
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/DefaultExceptionEvent.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/DefaultExceptionEvent.java
index f117c8d..f0c664e 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/DefaultExceptionEvent.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/DefaultExceptionEvent.java
@@ -20,7 +20,7 @@
 package org.apache.deltaspike.core.impl.exception.control;
 
 import org.apache.deltaspike.core.api.exception.control.ExceptionHandlingFlow;
-import org.apache.deltaspike.core.api.exception.control.ExceptionStack;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionStackEvent;
 import org.apache.deltaspike.core.spi.exception.control.IntrospectiveExceptionEvent;
 
 import javax.enterprise.inject.Typed;
@@ -46,19 +46,20 @@ public class DefaultExceptionEvent<T extends Throwable> implements Introspective
     /**
      * Initial state constructor.
      *
      * @param stack           Information about the current exception and cause chain.
      * @param beforeTraversal flag indicating the direction of the cause chain traversal
      * @param handled         flag indicating the exception has already been handled by a previous handler
      * @throws IllegalArgumentException if stack is null
      */
-    public DefaultExceptionEvent(final ExceptionStack stack, final boolean beforeTraversal, final boolean handled)
+    public DefaultExceptionEvent(final ExceptionStackEvent stackEvent, final boolean beforeTraversal,
+                                 final boolean handled)
     {
-        if (stack == null)
+        if (stackEvent == null)
         {
-            throw new IllegalArgumentException("null is not valid for stack");
+            throw new IllegalArgumentException("null is not valid for stackEvent");
         }
 
-        this.exception = (T) stack.getCurrent();
+        this.exception = (T) stackEvent.getCurrent();
         this.beforeTraversal = beforeTraversal;
         this.markedHandled = handled;
         this.flow = ExceptionHandlingFlow.HANDLED_AND_CONTINUE;
@@ -113,7 +114,7 @@ public class DefaultExceptionEvent<T extends Throwable> implements Introspective
     }
 
     /* Later
-    public ExceptionStack getExceptionStack() {
+    public ExceptionStackEvent getExceptionStack() {
     }
     */
 

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/ExceptionHandlerDispatch.java
----------------------------------------------------------------------
@@ -46,19 +46,20 @@ public class DefaultExceptionEvent<T extends Throwable> implements Introspective
      * Initial state constructor.
      *
-     * @param stack           Information about the current exception and cause chain.
+     * @param stackEvent           Information about the current exception and cause chain.
      * @param beforeTraversal flag indicating the direction of the cause chain traversal
      * @param handled         flag indicating the exception has already been handled by a previous handler
@@ -46,19 +46,20 @@ public class DefaultExceptionEvent<T extends Throwable> implements Introspective
      * @param beforeTraversal flag indicating the direction of the cause chain traversal
      * @param handled         flag indicating the exception has already been handled by a previous handler
-     * @throws IllegalArgumentException if stack is null
+     * @throws IllegalArgumentException if stackEvent is null
      */
diff --git a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/ExceptionHandlerDispatch.java b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/ExceptionHandlerDispatch.java
index 8700571..7554038 100644
--- a/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/ExceptionHandlerDispatch.java
+++ b/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/ExceptionHandlerDispatch.java
@@ -19,8 +19,8 @@
 
 package org.apache.deltaspike.core.impl.exception.control;
 
-import org.apache.deltaspike.core.api.exception.control.ExceptionStack;
-import org.apache.deltaspike.core.api.exception.control.ExceptionToCatch;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionStackEvent;
+import org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent;
 import org.apache.deltaspike.core.api.exception.control.HandlerMethod;
 import org.apache.deltaspike.core.api.provider.BeanProvider;
 
@@ -38,8 +38,8 @@ import java.util.Set;
 import java.util.logging.Logger;
 
 /**
  * Observer of {@link ExceptionToCatch} events and handler dispatcher. All handlers are invoked from this class.  This
  * class is immutable.
  */
 @ApplicationScoped
 @SuppressWarnings("UnusedDeclaration")
@@ -50,15 +50,15 @@ public class ExceptionHandlerDispatch
     /**
      * Observes the event, finds the correct exception handler(s) and invokes them.
      *
      * @param exceptionEvent exception to be invoked
      * @param beanManager    active bean manager
      * @throws Throwable If a handler requests the exception to be re-thrown.
      */
     @SuppressWarnings({ "unchecked", "MethodWithMultipleLoops", "ThrowableResultOfMethodCallIgnored" })
-    public void executeHandlers(@Observes @Any ExceptionToCatch exceptionEvent,
+    public void executeHandlers(@Observes @Any ExceptionToCatchEvent exceptionEventEvent,
                                 final BeanManager beanManager) throws Throwable
     {
-        LOG.entering(ExceptionHandlerDispatch.class.getName(), "executeHandlers", exceptionEvent.getException());
+        LOG.entering(ExceptionHandlerDispatch.class.getName(), "executeHandlers", exceptionEventEvent.getException());
 
         CreationalContext<Object> creationalContext = null;
 
@@ -73,7 +73,7 @@ public class ExceptionHandlerDispatch
 
             final Set<HandlerMethod<?>> processedHandlers = new HashSet<HandlerMethod<?>>();
 
-            final ExceptionStack stack = new ExceptionStack(exceptionEvent.getException());
+            final ExceptionStackEvent stack = new ExceptionStackEvent(exceptionEventEvent.getException());
 
             beanManager.fireEvent(stack); // Allow for modifying the exception stack
 
@@ -83,7 +83,7 @@ public class ExceptionHandlerDispatch
             {
                 final List<HandlerMethod<?>> callbackExceptionEvent = new ArrayList<HandlerMethod<?>>(
                         handlerMethodStorage.getHandlersForException(stack.getCurrent().getClass(),
-                                beanManager, exceptionEvent.getQualifiers(), true));
+                                beanManager, exceptionEventEvent.getQualifiers(), true));
 
                 for (HandlerMethod<?> handler : callbackExceptionEvent)
                 {
@@ -93,7 +93,7 @@ public class ExceptionHandlerDispatch
 
                         @SuppressWarnings("rawtypes")
                         final DefaultExceptionEvent callbackEvent = new DefaultExceptionEvent(stack, true,
-                                exceptionEvent.isHandled());
+                                exceptionEventEvent.isHandled());
 
                         handler.notify(callbackEvent);
 
@@ -108,19 +108,19 @@ public class ExceptionHandlerDispatch
                         switch (callbackEvent.getCurrentExceptionHandlingFlow())
                         {
                             case HANDLED:
-                                exceptionEvent.setHandled(true);
+                                exceptionEventEvent.setHandled(true);
                                 return;
                             case HANDLED_AND_CONTINUE:
-                                exceptionEvent.setHandled(true);
+                                exceptionEventEvent.setHandled(true);
                                 break;
                             case ABORT:
                                 return;
                             case SKIP_CAUSE:
-                                exceptionEvent.setHandled(true);
+                                exceptionEventEvent.setHandled(true);
                                 stack.skipCause();
                                 continue inbound_cause;
                             case THROW_ORIGINAL:
-                                throwException = exceptionEvent.getException();
+                                throwException = exceptionEventEvent.getException();
                                 break;
                             case THROW:
                                 throwException = callbackEvent.getThrowNewException();
@@ -134,7 +134,7 @@ public class ExceptionHandlerDispatch
 
                 final Collection<HandlerMethod<? extends Throwable>> handlersForException =
                         handlerMethodStorage.getHandlersForException(stack.getCurrent().getClass(),
-                                beanManager, exceptionEvent.getQualifiers(), false);
+                                beanManager, exceptionEventEvent.getQualifiers(), false);
 
                 final List<HandlerMethod<? extends Throwable>> handlerMethods =
                         new ArrayList<HandlerMethod<? extends Throwable>>(handlersForException);
@@ -150,7 +150,7 @@ public class ExceptionHandlerDispatch
 
                         @SuppressWarnings("rawtypes")
                         final DefaultExceptionEvent depthFirstEvent = new DefaultExceptionEvent(stack, false,
-                                exceptionEvent.isHandled());
+                                exceptionEventEvent.isHandled());
                         handler.notify(depthFirstEvent);
 
                         LOG.fine(String.format("Handler %s returned status %s", handler,
@@ -164,19 +164,19 @@ public class ExceptionHandlerDispatch
                         switch (depthFirstEvent.getCurrentExceptionHandlingFlow())
                         {
                             case HANDLED:
-                                exceptionEvent.setHandled(true);
+                                exceptionEventEvent.setHandled(true);
                                 return;
                             case HANDLED_AND_CONTINUE:
-                                exceptionEvent.setHandled(true);
+                                exceptionEventEvent.setHandled(true);
                                 break;
                             case ABORT:
                                 return;
                             case SKIP_CAUSE:
-                                exceptionEvent.setHandled(true);
+                                exceptionEventEvent.setHandled(true);
                                 stack.skipCause();
                                 continue inbound_cause;
                             case THROW_ORIGINAL:
-                                throwException = exceptionEvent.getException();
+                                throwException = exceptionEventEvent.getException();
                                 break;
                             case THROW:
                                 throwException = depthFirstEvent.getThrowNewException();
@@ -190,10 +190,10 @@ public class ExceptionHandlerDispatch
                 stack.skipCause();
             }
 
-            if (!exceptionEvent.isHandled() && throwException == null)
+            if (!exceptionEventEvent.isHandled() && throwException == null)
             {
-                LOG.warning(String.format("No handlers found for exception %s", exceptionEvent.getException()));
-                throw exceptionEvent.getException();
+                LOG.warning(String.format("No handlers found for exception %s", exceptionEventEvent.getException()));
+                throw exceptionEventEvent.getException();
             }
 
             if (throwException != null)
@@ -207,7 +207,8 @@ public class ExceptionHandlerDispatch
             {
                 creationalContext.release();
             }
-            LOG.exiting(ExceptionHandlerDispatch.class.getName(), "executeHandlers", exceptionEvent.getException());
+            LOG.exiting(ExceptionHandlerDispatch.class.getName(), "executeHandlers",
+                    exceptionEventEvent.getException());
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-deltaspike/blob/9c5194fe/deltaspike/core/impl/src/main/java/org/apache/deltaspike/core/impl/exception/control/HandlerMethodImpl.java
----------------------------------------------------------------------
@@ -38,8 +38,8 @@ import java.util.Set;
 
 /**
- * Observer of {@link ExceptionToCatch} events and handler dispatcher. All handlers are invoked from this class.  This
- * class is immutable.
+ * Observer of {@link org.apache.deltaspike.core.api.exception.control.event.ExceptionToCatchEvent} events and
+ * handler dispatcher. All handlers are invoked from this class.  This class is immutable.
  */
 @ApplicationScoped
@@ -50,15 +50,15 @@ public class ExceptionHandlerDispatch
      * Observes the event, finds the correct exception handler(s) and invokes them.
      *
-     * @param exceptionEvent exception to be invoked
+     * @param exceptionEventEvent exception to be invoked
      * @param beanManager    active bean manager
      * @throws Throwable If a handler requests the exception to be re-thrown.